@@ -161,6 +161,7 @@ class SvnCommand:
     def initClient( self, config_dir ):
         self.client = pysvn.Client( config_dir )
         self.client.exception_style = 1
+        self.client.commit_info_style = 1
         self.client.callback_get_login = self.callback_getLogin
         self.client.callback_get_log_message = self.callback_getLogMessage
         self.client.callback_notify = self.callback_notify
@@ -367,9 +368,13 @@ class SvnCommand:
         if msg == '':
             msg = self.getLogMessage()
             
-        rev = self.client.checkin( positional_args, msg, recurse=recurse )
+        commit_info = self.client.checkin( positional_args, msg, recurse=recurse )
+        rev = commit_info["revision"]
         self.printNotifyMessages()
 
+        if commit_info['post_commit_err'] is not None:
+            print( commit_info['post_commit_err'] )
+
         if rev is None:
             print( 'Nothing to commit' )
         elif rev.number > 0:
@@ -377,6 +382,7 @@ class SvnCommand:
         else:
             print( 'Commit failed' )
 
+
     cmd_commit = cmd_checkin
     cmd_ci = cmd_checkin
 
@@ -622,6 +628,27 @@ class SvnCommand:
                 for file in all_files:
                     print( '%(name)s' % file )
 
+    def cmd_list( self, args ):
+        recurse = args.getBooleanOption( '--recursive', True )
+        revision = args.getOptionalRevision( '--revision', 'head' )
+        verbose = args.getBooleanOption( '--verbose', True )
+        positional_args = args.getPositionalArgs( 0 )
+        if len(positional_args) == 0:
+            positional_args.append( '.' )
+
+        for arg in positional_args:
+            all_files = self.client.list( arg, revision=revision, recurse=recurse )
+            if verbose:
+                for file, Q in all_files:
+                    args = {}
+                    args.update( file )
+                    args['time_str'] = fmtDateTime( file.time )
+                    args['created_rev_num'] = file.created_rev.number
+                    print( '%(created_rev_num)7d %(last_author)-10s %(size)6d %(time_str)s %(path)s' % args )
+            else:
+                for file, Q in all_files:
+                    print( '%(path)s' % file )
+
     def cmd_merge( self, args ):
         recurse = args.getBooleanOption( '--recursive', True )
         dry_run = args.getBooleanOption( '--dry-run', False )
