@@ -3,15 +3,26 @@
 #
 import os
 
-print 'Info: setup vesion info'
+print( 'Info: setup vesion info' )
 import sys
 sys.path.insert( 0, '../../Source')
 import pysvn
 import time
-import popen2
 
-so, si = popen2.popen2( 'uname -p' )
-processor = so.read().strip()
+os.system( 'uname -p >./uname-p.tmp' )
+processor = open( 'uname-p.tmp' ).read().strip()
+os.remove( 'uname-p.tmp' )
+
+if processor == 'i386':
+    if hasattr( sys, 'maxsize' ):
+        maxsize = sys.maxsize
+    else:
+        maxsize = sys.maxint
+
+    if maxsize == (2**31-1):
+        processor = 'i386'
+    else:
+        processor = 'x86_64'
 
 pymaj, pymin, pypat, _, _ = sys.version_info
 python_version_string = '%d.%d.%d' % (pymaj, pymin, pypat)
@@ -22,16 +33,14 @@ svn_version_package_string = '%d%d%d' % (pysvn.svn_version[0], pysvn.svn_version
 svn_version_string = '%d.%d.%d' % (pysvn.svn_version[0], pysvn.svn_version[1], pysvn.svn_version[2])
 pysvn_so_string = '_pysvn_%d_%d.so' % (pymaj, pymin)
 pkg_filename = 'py%s%s_pysvn_svn%s-%s-%s' % (pymaj, pymin, svn_version_package_string, pysvn_version_string, processor)
-print 'Info: Packageing %s' % pkg_filename
+
+print( 'Info: Packageing %s' % pkg_filename )
 build_time  = time.time()
 build_time_str = time.strftime( '%d-%b-%Y %H:%M', time.localtime( build_time ) )
 year = time.strftime( '%Y', time.localtime( build_time ) )
 tmpdir = os.path.join( os.getcwd(), 'tmp' )
 
-if pymaj == 2 and pymin == 3:
-    install_dir = '/System/Library/Frameworks/Python.framework/Versions/2.3/lib/python2.3/site-packages'
-
-elif pymaj == 2 and pymin == 4:
+if pymaj == 2 and pymin == 4:
     install_dir = '/Library/Frameworks/Python.framework/Versions/2.4/lib/python2.4/site-packages'
 
 elif pymaj == 2 and pymin == 5:
@@ -40,14 +49,17 @@ elif pymaj == 2 and pymin == 5:
 elif pymaj == 2 and pymin == 6:
     install_dir = '/Library/Frameworks/Python.framework/Versions/2.6/lib/python2.6/site-packages'
 
+elif pymaj == 3 and pymin == 1:
+    install_dir = '/Library/Frameworks/Python.framework/Versions/3.1/lib/python3.1/site-packages'
+
 else:
     raise RuntimeError( 'Unsupported version of python' )
 
 if os.path.exists( tmpdir ):
-    print 'Info: Clean up tmp directory'
+    print( 'Info: Clean up tmp directory' )
     os.system( 'rm -rf tmp' )
 
-print 'Info: Create directories'
+print( 'Info: Create directories' )
 
 for kit_dir in [
     tmpdir,
@@ -63,30 +75,30 @@ for kit_dir in [
         os.makedirs( kit_dir )
 
 
-print 'Info: Finding dylibs used by pysvn'
+print( 'Info: Finding dylibs used by pysvn' )
 
 def findDylibs( image, dylib_list, depth=0 ):
     cmd = 'otool -L "%s" >/tmp/pysvn_otool.tmp' % image
-    #print 'Debug: cmd %r' % cmd
+    #print( 'Debug: cmd %r' % cmd )
     os.system( cmd )
     # always skip the first line that lists the image being dumped
-    for line in file( '/tmp/pysvn_otool.tmp' ).readlines()[1:]:
+    for line in open( '/tmp/pysvn_otool.tmp' ).readlines()[1:]:
         line = line.strip()
         libpath = line.split()[0]
-        #print 'Debug: line %r' % line
+        #print( 'Debug: line %r' % line )
         if( libpath.startswith( '/' )               # lines with libs on them
         and not libpath.startswith( '/usr/lib' )    # ignore libs shipped by Apple
         and not libpath.startswith( '/System' )     # ignore libs shipped by Apple
         and not libpath.endswith( '/Python' ) ):    # do not need to ignore python
             if libpath not in dylib_list:
-                #print 'Info: ',depth,' Need lib',libpath,'for',image
+                #print( 'Info: ',depth,' Need lib',libpath,'for',image )
                 dylib_list.append( libpath )
                 findDylibs( libpath, dylib_list, depth+1 )
         
 dylib_list = []
 findDylibs( '../../Source/pysvn/%s' % pysvn_so_string, dylib_list )
 
-print 'Info: Copy files'
+print( 'Info: Copy files' )
 
 cp_list = [
     ('../../Source/pysvn/__init__.py',
@@ -116,10 +128,10 @@ for libpath in dylib_list:
 
 for cp_src, cp_dst_dir_fmt in cp_list:
     cmd = 'cp -f "%s" "tmp/%s"' % (cp_src, cp_dst_dir_fmt % locals())
-    print 'Info:  %r' % cmd
+    print( 'Info:  %r' % cmd )
     os.system( cmd )
 
-print 'Info: Fix the install paths for the dylib files'
+print( 'Info: Fix the install paths for the dylib files' )
 
 fixup_path_list = ['tmp/Contents/pysvn/%s' % pysvn_so_string]
 for libpath in dylib_list:
@@ -134,11 +146,11 @@ for fixup_path in fixup_path_list:
                 ' %s/pysvn/%s'
                 ' %s' %
                     (libpath, install_dir, os.path.basename( libpath ), fixup_path) )
-            #print 'Debug: cmd %r' % cmd
+            #print( 'Debug: cmd %r' % cmd )
             os.system( cmd )
 
-print 'Info: Create tmp/Resources/ReadMe.txt'
-f = file('tmp/Resources/ReadMe.txt','w')
+print( 'Info: Create tmp/Resources/ReadMe.txt' )
+f = open('tmp/Resources/ReadMe.txt','w')
 f.write('''<html>
 <body>
 <h1>PySVN %(pysvn_version_string)s for Apple Mac OS X Python %(pymaj)s.%(pymin)s and Subversion %(svn_version_string)s</h1>
@@ -155,8 +167,8 @@ f.write('''<html>
 ''' % locals() )
 f.close()
 
-print 'Info: Create tmp/Info.plist'
-f = file('tmp/Info.plist','w')
+print( 'Info: Create tmp/Info.plist' )
+f = open('tmp/Info.plist','w')
 f.write('''<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
@@ -198,8 +210,8 @@ f.write('''<?xml version="1.0" encoding="UTF-8"?>
 ''' % locals() )
 f.close()
 
-print 'Info: Create tmp/Description.plist'
-f = file('tmp/Description.plist','w')
+print( 'Info: Create tmp/Description.plist' )
+f = open('tmp/Description.plist','w')
 f.write('''<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple Computer//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
@@ -214,7 +226,7 @@ f.write('''<?xml version="1.0" encoding="UTF-8"?>
 ''' )
 f.close()
 
-print 'Info: PackageMaker'
+print( 'Info: PackageMaker' )
 cmd = [    '/Developer/Applications/Utilities/PackageMaker.app/Contents/MacOS/PackageMaker',
     '-build',
     '-p %s' % os.path.abspath( 'tmp/%s/%s.pkg' % (pkg_filename, pkg_filename) ),
@@ -225,7 +237,7 @@ cmd = [    '/Developer/Applications/Utilities/PackageMaker.app/Contents/MacOS/Pa
     ]
 os.system( ' '.join( cmd ) )
 
-print 'Info: Make Disk Image'
+print( 'Info: Make Disk Image' )
 os.system( 'hdiutil create -srcfolder tmp/%s tmp/tmp.dmg' % pkg_filename )
 os.system( 'hdiutil convert tmp/tmp.dmg -format UDZO -imagekey zlib-level=9 ' 
         '-o tmp/%s.dmg' % pkg_filename )
