@@ -40,6 +40,7 @@ PYSVN_STATIC_STRING( name_changed_paths, "changed_paths" )
 PYSVN_STATIC_STRING( name_changelist, "changelist" )
 PYSVN_STATIC_STRING( name_changelists, "changelists" )
 PYSVN_STATIC_STRING( name_comment, "comment" )
+PYSVN_STATIC_STRING( name_commit_info_style, "commit_info_style" )
 PYSVN_STATIC_STRING( name_conflict_choice, "conflict_choice" )
 PYSVN_STATIC_STRING( name_copy_as_child, "copy_as_child" )
 PYSVN_STATIC_STRING( name_copyfrom_path, "copyfrom_path" )
@@ -141,6 +142,7 @@ PYSVN_STATIC_PY_STRING_P( py_name_callback_ssl_client_cert_password_prompt )
 PYSVN_STATIC_PY_STRING_P( py_name_callback_ssl_client_cert_prompt )
 PYSVN_STATIC_PY_STRING_P( py_name_callback_ssl_server_prompt )
 PYSVN_STATIC_PY_STRING_P( py_name_callback_ssl_server_trust_prompt )
+PYSVN_STATIC_PY_STRING_P( py_name_commit_info_style )
 PYSVN_STATIC_PY_STRING_P( py_name_created_rev )
 PYSVN_STATIC_PY_STRING_P( py_name_exception_style )
 PYSVN_STATIC_PY_STRING_P( py_name_has_props )
