@@ -1,6 +1,6 @@
 #!/bin/sh
 # need to get rid of any symbolic links in the WORKDIR
-export WORKDIR=$( ${PYTHON} -c 'import os;os.chdir("..");print os.getcwd()' )
+export WORKDIR=$( ${PYTHON} -c 'import os;os.chdir("..");print( os.getcwd() )' )
 
 cd ${WORKDIR}/Tests
 echo WorkDir: ${WORKDIR}
@@ -72,3 +72,11 @@ cmd ${PYSVN} checkin -m "Delete one file" ${TESTROOT}/wc
 echo Info: test_1.output start ----------------------------------------
 cat ${TESTROOT}/test_1.output
 echo Info: test_1.output end ------------------------------------------
+
+echo Info: Copy one file
+
+cmd ${PYSVN} cp ${TESTROOT}/wc/file1.txt ${TESTROOT}/wc/file1copy.txt
+cmd ${PYSVN} checkin -m "Copy one file" ${TESTROOT}/wc
+echo Info: test_1.output start ----------------------------------------
+cat ${TESTROOT}/test_1.output
+echo Info: test_1.output end ------------------------------------------
